@@ -91,7 +91,6 @@ class SharesReadWriteBase(base.BaseTestCase):
         self.assertEqual(self.description, get['description'])
         self.assertEqual('1', get['size'])
         self.assertEqual(self.protocol.upper(), get['share_proto'])
-        self.assertTrue(get.get('export_locations', []) > 0)
 
 
 @ddt.ddt
@@ -152,7 +151,7 @@ class SharesTestMigration(base.BaseTestCase):
             share_type=self.old_type['ID'],
             share_network=self.old_share_net['id'],
             wait_for_creation=True)
-        share = self.user_client.get_share(share['id'])
+        share = self.admin_client.get_share(share['id'])
 
         pools = self.admin_client.pool_list(detail=True)
 
